# DVote example

This plugin provides cryptographic and communication libraries to interact with decentralized votes running on the Vocdoni platform.

## Getting Started
Import the Dart library on your project and use the static functions available on the `Dvote` class

```dart
import 'package:dvote/dvote.dart';
```

## HD Wallet management
Generating mnemonics and computing private/public keys

```dart
final mnemonic = await Dvote.generateMnemonic();
final privateKey = await Dvote.mnemonicToPrivateKey(mnemonic, hdPath: "m/44'/60'/0'/0/5");
final publicKey = await Dvote.mnemonicToPublicKey(mnemonic);
final address = await Dvote.mnemonicToAddress(mnemonic);
```

## Signing
Computing signatures using ECDSA cryptography

```dart
final signature = await Dvote.signString(messageToSign, privateKey);
final valid = await Dvote.verifySignature(signature, messageToSign, publicKey);
```

## Encryption
Using symmetric AES-GCM encryption to store private data on a mobile device

```dart
final encrypted = await Dvote.encryptString(myText, myPassphrase);
final decrypted = await Dvote.decryptString(encrypted, myPassphrase);
```

## Entity API
Use a Vocdoni Gateway to fetch the metadata of an Entity

```dart
import 'package:dvote/dvote.dart';

final entityMeta = await fetchEntity(
    entityId,
    resolverAddress,
    "1234",   // network id
    vocGateway,
    web3GatewayUri
);

```

## File API
Use a Vocdoni Gateway to fetch static content from the net

```dart
import 'package:dvote/dvote.dart';

final contentUri = ContentURI("ipfs://QmSsfizN4rpSDLRZw3X3WooCPpnBktZ5bEShvmLZuf88iw,https://my-server/file.txt");
final gatewayUri = "ws://hostname:2082/dvote";

final content = await fetchFileString(contentUri, gatewayUri);
```
